@@ -1,6 +1,6 @@
 #!/usr/bin/python
 
-## Copyright (C) 2007, 2008, 2009, 2010, 2011, 2013 Red Hat, Inc.
+## Copyright (C) 2007, 2008, 2009, 2010, 2011, 2012, 2013 Red Hat, Inc.
 ## Copyright (C) 2008 Novell, Inc.
 ## Author: Tim Waugh <twaugh@redhat.com>
 
@@ -21,8 +21,10 @@
 import threading
 import config
 import cups
-import gobject
-import gtk
+from gi.repository import GObject
+from gi.repository import GLib
+from gi.repository import Gdk
+from gi.repository import Gtk
 import Queue
 
 cups.require ("1.9.60")
@@ -164,44 +166,44 @@ class _IPPConnectionThread(threading.Thread):
 
     def _auth (self, prompt, conn=None, method=None, resource=None):
         def prompt_auth (prompt):
-            gtk.gdk.threads_enter ()
+            Gdk.threads_enter ()
             if conn == None:
                 self._auth_handler (prompt, self._conn)
             else:
                 self._auth_handler (prompt, self._conn, method, resource)
 
-            gtk.gdk.threads_leave ()
+            Gdk.threads_leave ()
             return False
 
         if self._auth_handler == None:
             return ""
 
-        gobject.idle_add (prompt_auth, prompt)
+        GLib.idle_add (prompt_auth, prompt)
         password = self._auth_queue.get ()
         return password
 
     def _reply (self, result):
         def send_reply (handler, result):
             if not self._destroyed:
-                gtk.gdk.threads_enter ()
+                Gdk.threads_enter ()
                 handler (self._conn, result)
-                gtk.gdk.threads_leave ()
+                Gdk.threads_leave ()
             return False
 
         if not self._destroyed and self._reply_handler:
-            gobject.idle_add (send_reply, self._reply_handler, result)
+            GLib.idle_add (send_reply, self._reply_handler, result)
 
     def _error (self, exc):
         def send_error (handler, exc):
             if not self._destroyed:
-                gtk.gdk.threads_enter ()
+                Gdk.threads_enter ()
                 handler (self._conn, exc)
-                gtk.gdk.threads_leave ()
+                Gdk.threads_leave ()
             return False
 
         if not self._destroyed and self._error_handler:
             debugprint ("Add %s to idle" % self._error_handler)
-            gobject.idle_add (send_error, self._error_handler, exc)
+            GLib.idle_add (send_error, self._error_handler, exc)
 
 ###
 ### This is the user-visible class.  Although it does not inherit from
@@ -259,7 +261,7 @@ class IPPConnection:
             delattr (self, binding)
 
         if self.thread.isAlive ():
-            gobject.timeout_add_seconds (1, self._reap_thread)
+            GLib.timeout_add_seconds (1, self._reap_thread)
 
     def _reap_thread (self):
         if self.thread.idle:
@@ -455,11 +457,11 @@ class _IPPAuthOperation:
 
         # If we've previously prompted, explain why we're prompting again.
         if self._dialog_shown:
-            d = gtk.MessageDialog (self._conn.parent,
-                                   gtk.DIALOG_MODAL |
-                                   gtk.DIALOG_DESTROY_WITH_PARENT,
-                                   gtk.MESSAGE_ERROR,
-                                   gtk.BUTTONS_CLOSE,
+            d = Gtk.MessageDialog (self._conn.parent,
+                                   Gtk.DialogFlags.MODAL |
+                                   Gtk.DialogFlags.DESTROY_WITH_PARENT,
+                                   Gtk.MessageType.ERROR,
+                                   Gtk.ButtonsType.CLOSE,
                                    _("Not authorized"))
             d.format_secondary_text (_("The password may be incorrect."))
             d.run ()
@@ -507,8 +509,8 @@ class _IPPAuthOperation:
         self._dialog = dialog
         dialog.hide ()
 
-        if (response == gtk.RESPONSE_CANCEL or
-            response == gtk.RESPONSE_DELETE_EVENT):
+        if (response == Gtk.ResponseType.CANCEL or
+            response == Gtk.ResponseType.DELETE_EVENT):
             self._cancel = True
             self._conn.set_auth_info ('')
             authconn.global_authinfocache.remove_auth_info (host=self._conn.thread.host,
@@ -551,11 +553,11 @@ class _IPPAuthOperation:
         else:
             msg = _("CUPS server error (%s)") % op
 
-        d = gtk.MessageDialog (self._conn.parent,
-                               gtk.DIALOG_MODAL |
-                               gtk.DIALOG_DESTROY_WITH_PARENT,
-                               gtk.MESSAGE_ERROR,
-                               gtk.BUTTONS_NONE,
+        d = Gtk.MessageDialog (self._conn.parent,
+                               Gtk.DialogFlags.MODAL |
+                               Gtk.DialogFlags.DESTROY_WITH_PARENT,
+                               Gtk.MessageType.ERROR,
+                               Gtk.ButtonsType.NONE,
                                msg)
 
         if self._client_fn == None and type (exc) == RuntimeError:
@@ -568,9 +570,9 @@ class _IPPAuthOperation:
 
         d.format_secondary_text (_("There was an error during the "
                                    "CUPS operation: '%s'." % message))
-        d.add_buttons (gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
-                       _("Retry"), gtk.RESPONSE_OK)
-        d.set_default_response (gtk.RESPONSE_OK)
+        d.add_buttons (Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL,
+                       _("Retry"), Gtk.ResponseType.OK)
+        d.set_default_response (Gtk.ResponseType.OK)
         d.connect ("response", self._on_retry_server_error_response)
         debugprint ("%s (_reconnect_error): presenting error dialog (%s; %s)" %
                     (self, msg, message))
@@ -578,7 +580,7 @@ class _IPPAuthOperation:
 
     def _on_retry_server_error_response (self, dialog, response):
         dialog.destroy ()
-        if response == gtk.RESPONSE_OK:
+        if response == Gtk.ResponseType.OK:
             debugprint ("%s: got retry response, reconnecting (as %s)..." %
                         (self, self._conn.thread.user))
             self._conn.reconnect (self._conn.thread.user,
@@ -652,22 +654,21 @@ class IPPAuthConnection(IPPConnection):
 
 if __name__ == "__main__":
     # Demo
-    import gtk
     set_debugging (True)
-    gobject.threads_init ()
+    GObject.threads_init ()
     class UI:
         def __init__ (self):
-            w = gtk.Window ()
+            w = Gtk.Window ()
             w.connect ("destroy", self.destroy)
-            b = gtk.Button ("Connect")
+            b = Gtk.Button ("Connect")
             b.connect ("clicked", self.connect_clicked)
-            vbox = gtk.VBox ()
-            vbox.pack_start (b)
+            vbox = Gtk.VBox ()
+            vbox.pack_start (b, False, False, 0)
             w.add (vbox)
-            self.get_devices_button = gtk.Button ("Get Devices")
+            self.get_devices_button = Gtk.Button ("Get Devices")
             self.get_devices_button.connect ("clicked", self.get_devices)
             self.get_devices_button.set_sensitive (False)
-            vbox.pack_start (self.get_devices_button)
+            vbox.pack_start (self.get_devices_button, False, False, 0)
             self.conn = None
             w.show_all ()
 
@@ -677,7 +678,7 @@ if __name__ == "__main__":
             except AttributeError:
                 pass
 
-            gtk.main_quit ()
+            Gtk.main_quit ()
 
         def connect_clicked (self, button):
             if self.conn:
@@ -718,4 +719,4 @@ if __name__ == "__main__":
             self.get_devices_button.set_sensitive (True)
 
     UI ()
-    gtk.main ()
+    Gtk.main ()
