@@ -1,8 +1,8 @@
 # vim: set ts=4 sw=4 et: coding=UTF-8
 #
 # Copyright (C) 2008 Novell, Inc.
-# Copyright (C) 2008, 2009, 2010 Red Hat, Inc.
-# Copyright (C) 2008, 2009, 2010 Tim Waugh <twaugh@redhat.com>
+# Copyright (C) 2008, 2009, 2010, 2012 Red Hat, Inc.
+# Copyright (C) 2008, 2009, 2010, 2012 Tim Waugh <twaugh@redhat.com>
 #
 # Authors: Vincent Untz
 #
@@ -18,7 +18,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #
 
 # check FIXME/TODO here
@@ -33,7 +33,6 @@ import tempfile
 
 import cups
 import dbus
-import gtk
 from debug import debugprint
 
 from dbus.mainloop.glib import DBusGMainLoop
