@@ -1,6 +1,6 @@
 #!/usr/bin/python
 
-## Copyright (C) 2009, 2010 Red Hat, Inc.
+## Copyright (C) 2009, 2010, 2012 Red Hat, Inc.
 ## Authors:
 ##  Tim Waugh <twaugh@redhat.com>
 
@@ -18,18 +18,18 @@
 ## along with this program; if not, write to the Free Software
 ## Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-import gtk
+from gi.repository import Gdk
+from gi.repository import Gtk
 import cairo
 
-class GtkInkLevel (gtk.DrawingArea):
+class GtkInkLevel (Gtk.DrawingArea):
     def __init__ (self, color, level=0):
-        gtk.DrawingArea.__init__ (self)
-        self.connect ('expose-event', self.expose_event)
+        Gtk.DrawingArea.__init__ (self)
+        self.connect ('draw', self.draw)
         self._level = level
-        try:
-            self._color = gtk.gdk.color_parse (color)
-        except (ValueError, TypeError):
-            self._color = gtk.gdk.color_parse ('#cccccc')
+        self._color = Gdk.color_parse (color)
+        if not self._color:
+            self._color = Gdk.color_parse ('#cccccc')
 
         self.set_size_request (30, 45)
 
@@ -40,14 +40,9 @@ class GtkInkLevel (gtk.DrawingArea):
     def get_level (self):
         return self._level
 
-    def expose_event (self, widget, event):
-        ctx = self.window.cairo_create ()
-        ctx.rectangle (event.area.x, event.area.y,
-                       event.area.width,
-                       event.area.height)
-        ctx.clip ()
-
-        (w, h) = self.window.get_size ()
+    def draw (self, widget, ctx):
+        w = widget.get_allocated_width ()
+        h = widget.get_allocated_height ()
         ratio = 1.0 * h / w
         if ratio < 1.5:
             w = h * 2.0 / 3.0
@@ -57,9 +52,7 @@ class GtkInkLevel (gtk.DrawingArea):
         ctx.translate (thickness, thickness)
         ctx.scale (w - 2 * thickness, h - 2 * thickness)
         thickness = max (ctx.device_to_user_distance (thickness, thickness))
-        self.draw (ctx, thickness)
 
-    def draw (self, ctx, thickness):
         r = self._color.red / 65535.0
         g = self._color.green / 65535.0
         b = self._color.blue / 65535.0
@@ -118,37 +111,37 @@ class GtkInkLevel (gtk.DrawingArea):
 
 if __name__ == '__main__':
     # Try it out.
-    import gobject
+    from gi.repository import GLib
     import time
     def adjust_level (level):
-        gtk.gdk.threads_enter ()
+        Gdk.threads_enter ()
         l = level.get_level ()
         l += 1
         if l > 100:
             l = 0
         level.set_level (l)
-        gtk.gdk.threads_leave ()
+        Gdk.threads_leave ()
         return True
 
-    w = gtk.Window ()
+    w = Gtk.Window ()
     w.set_border_width (12)
-    vbox = gtk.VBox (spacing=6)
+    vbox = Gtk.VBox (spacing=6)
     w.add (vbox)
-    hbox = gtk.HBox (spacing=6)
+    hbox = Gtk.HBox (spacing=6)
     vbox.pack_start (hbox, False, False, 0)
     klevel = GtkInkLevel ("black", level=100)
     clevel = GtkInkLevel ("cyan", level=60)
     mlevel = GtkInkLevel ("magenta", level=30)
     ylevel = GtkInkLevel ("yellow", level=100)
-    hbox.pack_start (klevel)
-    hbox.pack_start (clevel)
-    hbox.pack_start (mlevel)
-    hbox.pack_start (ylevel)
-    gobject.timeout_add (10, adjust_level, klevel)
-    gobject.timeout_add (10, adjust_level, clevel)
-    gobject.timeout_add (10, adjust_level, mlevel)
-    gobject.timeout_add (10, adjust_level, ylevel)
+    hbox.pack_start (klevel, False, False, 0)
+    hbox.pack_start (clevel, False, False, 0)
+    hbox.pack_start (mlevel, False, False, 0)
+    hbox.pack_start (ylevel, False, False, 0)
+    GLib.timeout_add (10, adjust_level, klevel)
+    GLib.timeout_add (10, adjust_level, clevel)
+    GLib.timeout_add (10, adjust_level, mlevel)
+    GLib.timeout_add (10, adjust_level, ylevel)
     w.show_all ()
-    w.connect ('delete_event', gtk.main_quit)
-    gtk.gdk.threads_init ()
-    gtk.main ()
+    w.connect ('delete_event', Gtk.main_quit)
+    Gdk.threads_init ()
+    Gtk.main ()
