@@ -1,6 +1,6 @@
 #!/usr/bin/python
 
-## Copyright (C) 2010 Red Hat, Inc.
+## Copyright (C) 2010, 2011, 2012 Red Hat, Inc.
 ## Authors:
 ##  Tim Waugh <twaugh@redhat.com>
 
@@ -20,12 +20,15 @@
 
 import asyncconn
 import cups
-import gobject
-import gtk
+from gi.repository import GLib
+from gi.repository import Gdk
+from gi.repository import Gtk
 import os
 import tempfile
 from debug import *
 
+cups.require ("1.9.50")
+
 class PPDCache:
     def __init__ (self, host=None, port=None, encryption=None):
         self._cups = None
@@ -71,20 +74,11 @@ class PPDCache:
                 return
 
             debugprint ("%s: fetch PPD for %s" % (self, name))
-            try:
-                self._cups.getPPD3 (name,
-                                    reply_handler=lambda c, r:
-                                        self._got_ppd3 (c, name, r, callback),
-                                    error_handler=lambda c, r:
-                                        self._got_ppd3 (c, name, r, callback))
-            except AttributeError:
-                # getPPD3 requires pycups >= 1.9.50
-                self._cups.getPPD (name,
-                                   reply_handler=lambda c, r:
-                                       self._got_ppd (c, name, r, callback),
-                                   error_handler=lambda c, r:
-                                       self._got_ppd (c, name, r, callback))
-
+            self._cups.getPPD3 (name,
+                                reply_handler=lambda c, r:
+                                    self._got_ppd3 (c, name, r, callback),
+                                error_handler=lambda c, r:
+                                    self._got_ppd3 (c, name, r, callback))
             return
 
         # Copy from our file object to a new temporary file, create a
@@ -95,6 +89,7 @@ class PPDCache:
         tmpf = file (tmpfname, "w")
         tmpf.writelines (f.readlines ())
         del tmpf
+        os.close (tmpfd)
         try:
             ppd = cups.PPD (tmpfname)
             os.unlink (tmpfname)
@@ -114,28 +109,47 @@ class PPDCache:
         if isinstance (result, Exception):
             self._schedule_callback (callback, name, result, None)
         else:
-            debugprint ("%s: caching %s" % (self, result))
             # Store an open file object, then remove the actual file.
             # This way we don't leave temporary files around.
             self._cache[name] = file (result)
+            debugprint ("%s: caching %s (fd %d)" % (self, result,
+                                                    self._cache[name].fileno()))
             os.unlink (result)
             self.fetch_ppd (name, callback)
 
     def _got_ppd3 (self, connection, name, result, callback):
         (status, modtime, filename) = result
         if status in [cups.HTTP_OK, cups.HTTP_NOT_MODIFIED]:
-            if status == cups.HTTP_OK:
-                debugprint ("%s: caching %s (%s) - %s" % (self,
-                                                          filename,
-                                                          modtime,
-                                                          status))
+            if status == cups.HTTP_NOT_MODIFIED:
+                # The file is no newer than the one we already have.
+
+                # CUPS before 1.5.3 created a temporary file in error
+                # in this situation (STR #4018) so remove that.
+                try:
+                    os.unlink (filename)
+                except OSError:
+                    pass
+
+            elif status == cups.HTTP_OK:
+                # Our version of the file was older.  Cache the new version.
+
                 # Store an open file object, then remove the actual
                 # file.  This way we don't leave temporary files
                 # around.
-                self._cache[name] = file (filename)
-                os.unlink (filename)
-                self._modtimes[name] = modtime
+                try:
+                    self._cache[name] = file (filename)
+                    debugprint ("%s: caching %s (fd %d) "
+                                "(%s) - %s" % (self, filename,
+                                               self._cache[name].fileno (),
+                                               modtime, status))
+                    os.unlink (filename)
+                    self._modtimes[name] = modtime
+                except IOError:
+                    # File disappeared?
+                    debugprint ("%s: file %s disappeared? Unable to cache it"
+                                % (self, filename))
 
+            # Now fetch it from our own cache.
             self.fetch_ppd (name, callback, check_uptodate=False)
         else:
             self._schedule_callback (callback, name,
@@ -156,20 +170,21 @@ class PPDCache:
 
     def _schedule_callback (self, callback, name, result, exc):
         def cb_func (callback, name, result, exc):
-            gtk.gdk.threads_enter ()
+            Gdk.threads_enter ()
             callback (name, result, exc)
-            gtk.gdk.threads_leave ()
+            Gdk.threads_leave ()
             return False
 
-        gobject.idle_add (cb_func, callback, name, result, exc)
+        GLib.idle_add (cb_func, callback, name, result, exc)
 
 if __name__ == "__main__":
     import sys
     from debug import *
+    from gi.repository import GObject
     set_debugging (True)
-    gobject.threads_init ()
-    gtk.gdk.threads_init ()
-    loop = gobject.MainLoop ()
+    GObject.threads_init ()
+    Gdk.threads_init ()
+    loop = GObject.MainLoop ()
 
     def signal (name, result, exc):
         debugprint ("**** %s" % name)
@@ -186,5 +201,6 @@ if __name__ == "__main__":
         cache.fetch_ppd (p, signal)
 
     if p:
-        gobject.timeout_add_seconds (1, cache.fetch_ppd, p, signal)
+        GLib.timeout_add_seconds (1, cache.fetch_ppd, p, signal)
+        GLib.timeout_add_seconds (5, loop.quit)
     loop.run ()
