@@ -2,7 +2,7 @@
 
 ## system-config-printer
 
-## Copyright (C) 2010, 2011, 2013 Red Hat, Inc.
+## Copyright (C) 2010, 2011, 2012, 2013 Red Hat, Inc.
 ## Author: Tim Waugh <twaugh@redhat.com>
 
 ## This program is free software; you can redistribute it and/or modify
@@ -20,8 +20,8 @@
 ## Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 import dbus
-import gobject
-import gtk
+from gi.repository import GObject
+from gi.repository import Gtk
 import cupshelpers
 
 import cups
@@ -31,7 +31,7 @@ import asyncconn
 from debug import debugprint
 from gettext import gettext as _
 
-class PPDsLoader(gobject.GObject):
+class PPDsLoader(GObject.GObject):
     """
     1. If PackageKit support is available, and this is a local server,
     try to use PackageKit to install relevant drivers.  We do this
@@ -48,13 +48,13 @@ class PPDsLoader(gobject.GObject):
     """
 
     __gsignals__ = {
-        'finished': (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, [])
+        'finished': (GObject.SIGNAL_RUN_LAST, None, ())
         }
 
     def __init__ (self, device_id=None, parent=None, device_uri=None,
                   host=None, encryption=None, language=None,
                   device_make_and_model=None):
-        gobject.GObject.__init__ (self)
+        GObject.GObject.__init__ (self)
         debugprint ("+%s" % self)
         self._device_id = device_id
         self._device_uri = device_uri
@@ -82,11 +82,11 @@ class PPDsLoader(gobject.GObject):
             self._bus = None
 
         fmt = _("Searching")
-        self._dialog = gtk.MessageDialog (parent=parent,
-                                          flags=gtk.DIALOG_MODAL |
-                                          gtk.DIALOG_DESTROY_WITH_PARENT,
-                                          type=gtk.MESSAGE_INFO,
-                                          buttons=gtk.BUTTONS_CANCEL,
+        self._dialog = Gtk.MessageDialog (parent=parent,
+                                          flags=Gtk.DialogFlags.MODAL |
+                                          Gtk.DialogFlags.DESTROY_WITH_PARENT,
+                                          type=Gtk.MessageType.INFO,
+                                          buttons=Gtk.ButtonsType.CANCEL,
                                           message_format=fmt)
 
         self._dialog.format_secondary_text (_("Searching for drivers"))
@@ -208,11 +208,6 @@ class PPDsLoader(gobject.GObject):
 
     def _query_packagekit (self):
         debugprint ("Asking PackageKit to install drivers")
-        try:
-            xid = self._parent.window.xid
-        except:
-            xid = 0
-
         try:
             obj = self._bus.get_object ("org.freedesktop.PackageKit",
                                         "/org/freedesktop/PackageKit")
@@ -220,8 +215,8 @@ class PPDsLoader(gobject.GObject):
             resources = [self._gpk_device_id]
             interaction = "hide-finished"
             debugprint ("Calling InstallPrinterDrivers (%s, %s, %s)" %
-                        (repr (xid), repr (resources), repr (interaction)))
-            proxy.InstallPrinterDrivers (dbus.UInt32 (xid),
+                        (repr (0), repr (resources), repr (interaction)))
+            proxy.InstallPrinterDrivers (dbus.UInt32 (0),
                                          resources, interaction,
                                          reply_handler=self._packagekit_reply,
                                          error_handler=self._packagekit_error,
@@ -281,16 +276,14 @@ class PPDsLoader(gobject.GObject):
 
             self.emit ('finished')
 
-gobject.type_register(PPDsLoader)
-
 if __name__ == "__main__":
     class Foo:
         def __init__ (self):
-            w = gtk.Window ()
-            b = gtk.Button ("Go")
+            w = Gtk.Window ()
+            b = Gtk.Button ("Go")
             w.add (b)
             b.connect ('clicked', self.go)
-            w.connect ('delete-event', gtk.main_quit)
+            w.connect ('delete-event', Gtk.main_quit)
             w.show_all ()
             self._window = w
 
@@ -302,7 +295,7 @@ if __name__ == "__main__":
 
         def ppds_loaded (self, ppdsloader):
             self._window.destroy ()
-            gtk.main_quit ()
+            Gtk.main_quit ()
             exc = ppdsloader.get_error ()
             print exc
             ppds = ppdsloader.get_ppds ()
@@ -311,9 +304,8 @@ if __name__ == "__main__":
 
             ppdsloader.destroy ()
 
-    import gobject
     from debug import set_debugging
     set_debugging (True)
-    gobject.threads_init ()
+    GObject.threads_init ()
     Foo ()
-    gtk.main ()
+    Gtk.main ()
