@@ -1,6 +1,6 @@
 ## system-config-printer
 
-## Copyright (C) 2006, 2007, 2008, 2009, 2010, 2011 Red Hat, Inc.
+## Copyright (C) 2006, 2007, 2008, 2009, 2010, 2011, 2012 Red Hat, Inc.
 ## Copyright (C) 2006 Florian Festi <ffesti@redhat.com>
 ## Copyright (C) 2007, 2008, 2009 Tim Waugh <twaugh@redhat.com>
 
@@ -22,13 +22,15 @@ import cupshelpers
 from debug import *
 import errno
 import socket, time
-import gtk
+from gi.repository import Gdk
+from gi.repository import Gtk
 from timedops import TimedOperation
 import subprocess
 import threading
 import errno
 import cups
-import gobject
+from gi.repository import GObject
+from gi.repository import GLib
 import smburi
 
 try:
@@ -180,8 +182,8 @@ class LpdServer:
     def probe(self):
         result = []
         for name in self.get_possible_queue_names ():
-            while gtk.events_pending ():
-                gtk.main_iteration ()
+            while Gtk.events_pending ():
+                Gtk.main_iteration ()
 
             if self.stop:
                 break
@@ -206,9 +208,9 @@ class BackgroundSmbAuthContext(pysmb.AuthContext):
         pysmb.AuthContext.__init__ (self, *args, **kwargs)
 
     def _do_perform_authentication (self):
-        gtk.gdk.threads_enter ()
+        Gdk.threads_enter ()
         result = pysmb.AuthContext.perform_authentication (self)
-        gtk.gdk.threads_leave ()
+        Gdk.threads_leave ()
         self._do_perform_authentication_result = result
         self._gui_event.set ()
         
@@ -221,7 +223,7 @@ class BackgroundSmbAuthContext(pysmb.AuthContext):
             return pysmb.AuthContext.perform_authentication (self)
 
         self._gui_event.clear ()
-        gobject.timeout_add (1, self._do_perform_authentication)
+        GLib.timeout_add (1, self._do_perform_authentication)
         self._gui_event.wait ()
         return self._do_perform_authentication_result
 
@@ -494,7 +496,7 @@ if __name__ == '__main__':
         sys.exit (1)
 
     set_debugging (True)
-    loop = gobject.MainLoop ()
+    loop = GObject.MainLoop ()
 
     def display (device):
         if device == None:
