@@ -2,7 +2,7 @@
 
 ## Printing troubleshooter
 
-## Copyright (C) 2008 Red Hat, Inc.
+## Copyright (C) 2008, 2012 Red Hat, Inc.
 ## Copyright (C) 2008 Tim Waugh <twaugh@redhat.com>
 
 ## This program is free software; you can redistribute it and/or modify
@@ -19,8 +19,15 @@
 ## along with this program; if not, write to the Free Software
 ## Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
+from gi.repository import Gtk
+
+class NoPrinter:
+    pass
+
+NotListed = NoPrinter()
+
 import cups
-import gobject
+from gi.repository import GObject
 from timedops import TimedOperation
 from base import *
 class ChoosePrinter(Question):
@@ -32,13 +39,13 @@ class ChoosePrinter(Question):
                                      "trying to use from the list below. "
                                      "If it does not appear in the list, "
                                      "select 'Not listed'."))
-        tv = gtk.TreeView ()
-        name = gtk.TreeViewColumn (_("Name"),
-                                   gtk.CellRendererText (), text=0)
-        location = gtk.TreeViewColumn (_("Location"),
-                                       gtk.CellRendererText (), text=1)
-        info = gtk.TreeViewColumn (_("Information"),
-                                   gtk.CellRendererText (), text=2)
+        tv = Gtk.TreeView ()
+        name = Gtk.TreeViewColumn (_("Name"),
+                                   Gtk.CellRendererText (), text=0)
+        location = Gtk.TreeViewColumn (_("Location"),
+                                       Gtk.CellRendererText (), text=1)
+        info = Gtk.TreeViewColumn (_("Information"),
+                                   Gtk.CellRendererText (), text=2)
         name.set_property ("resizable", True)
         location.set_property ("resizable", True)
         info.set_property ("resizable", True)
@@ -46,22 +53,22 @@ class ChoosePrinter(Question):
         tv.append_column (location)
         tv.append_column (info)
         tv.set_rules_hint (True)
-        sw = gtk.ScrolledWindow ()
-        sw.set_policy (gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
-        sw.set_shadow_type (gtk.SHADOW_IN)
+        sw = Gtk.ScrolledWindow ()
+        sw.set_policy (Gtk.PolicyType.AUTOMATIC, Gtk.PolicyType.AUTOMATIC)
+        sw.set_shadow_type (Gtk.ShadowType.IN)
         sw.add (tv)
         page1.pack_start (sw, True, True, 0)
         self.treeview = tv
         troubleshooter.new_page (page1, self)
 
     def display (self):
-        model = gtk.ListStore (gobject.TYPE_STRING,
-                               gobject.TYPE_STRING,
-                               gobject.TYPE_STRING,
-                               gobject.TYPE_PYOBJECT)
+        model = Gtk.ListStore (str,
+                               str,
+                               str,
+                               GObject.TYPE_PYOBJECT)
         self.treeview.set_model (model)
         iter = model.append (None)
-        model.set (iter, 0, _("Not listed"), 1, '', 2, '', 3, None)
+        model.set (iter, 0, _("Not listed"), 1, '', 2, '', 3, NotListed)
 
         parent = self.troubleshooter.get_window ()
         try:
@@ -122,7 +129,7 @@ class ChoosePrinter(Question):
     def collect_answer (self):
         model, iter = self.treeview.get_selection ().get_selected ()
         dest = model.get_value (iter, 3)
-        if dest == None:
+        if dest == NotListed:
             class enum_dests:
                 def __init__ (self, model):
                     self.dests = []
@@ -130,7 +137,7 @@ class ChoosePrinter(Question):
 
                 def each (self, model, path, iter, user_data):
                     dest = model.get_value (iter, 3)
-                    if dest:
+                    if dest != NotListed:
                         self.dests.append ((dest.name, dest.instance))
 
             return { 'cups_queue_listed': False,
